<template>
    <div class="flex">
        <div class="dialog-chart-contaienr">
            <div class="chart-content">
                <div class="sub-title">领域分类</div>
                <div
                    :element-loading-background="loadingColor"
                    v-loading="chartLoading"
                    id="pieChart"
                ></div>
            </div>
            <div class="chart-content">
                <div class="sub-title">过程管理</div>
                <div
                    class="manager-content"
                    :element-loading-background="loadingColor"
                    v-loading="chartLoading"
                >
                    <template v-if="!chartLoading">
                        <div
                            class="item-container"
                            v-for="item in processData"
                            :key="item.value"
                        >
                            <div class="manager-item">
                                <div
                                    :class="`manager-item-inner item-${item.value}`"
                                >
                                    {{ item.num }}项
                                </div>
                            </div>
                            <div
                                :class="`manager-item-text item-${item.value}`"
                            >
                                {{ item.name }}
                            </div>
                        </div>
                    </template>
                </div>
            </div>
        </div>
        <div class="dialog-table-container">
            <div class="sub-title">改革需求清单</div>
            <div>
                <el-input
                    @change="search"
                    size="small"
                    v-model="stage"
                    clearable
                    suffix-icon="el-icon-search"
                    placeholder="请输入清单期号"
                    style="width: 180px; margin-bottom: 10px"
                ></el-input>
            </div>
            <div class="table-contaier" ref="tableContaier">
                <el-table
                    :element-loading-background="loadingColor"
                    v-loading="loading"
                    align="center"
                    :data="tableData"
                    :max-height="tableHeight"
                    class="dialog_table"
                    :cell-style="{'text-align': 'center'}"
                    :header-cell-style="{'text-align': 'center'}"
                    ref="myTable"
                >
                    <el-table-column type="index" label="序号" width="60">
                    </el-table-column>
                    <el-table-column
                        prop="demandTopic"
                        label="需求题目"
                        width="300"
                    >
                    </el-table-column>
                    <el-table-column
                        prop="demandSourceChannel"
                        label="来源渠道"
                        width="200"
                    >
                        <template slot-scope="props">
                            {{
                                getDictName(
                                    'ggbb_lyqd',
                                    props.row.demandSourceChannel
                                )
                            }}
                        </template>
                    </el-table-column>
                    <el-table-column prop="demandField" label="所属领域">
                        <template slot-scope="props">
                            {{
                                getDictName('ggbb_ssly', props.row.demandField)
                            }}
                        </template>
                    </el-table-column>
                    <el-table-column prop="demandNo" label="清单期号">
                        <template slot-scope="props">
                            {{ props.row.propulsiveYear }}年{{
                                props.row.demandNo
                            }}期
                        </template>
                    </el-table-column>
                    <el-table-column
                        prop="responsibleUnitName"
                        label="责任区县"
                    ></el-table-column>
                    <el-table-column type="expand" label="" width="0">
                        <template slot-scope="props">
                            <el-descriptions
                                :column="1"
                                border
                                :labelStyle="{width: '1%'}"
                            >
                                <el-descriptions-item label="推进状态：">{{
                                    getDictName(
                                        'tjzt',
                                        props.row.propulsiveStatus
                                    )
                                }}</el-descriptions-item>
                                <el-descriptions-item label="已开展的工作：">{{
                                    props.row.propulsiveDetailed
                                }}</el-descriptions-item>
                                <el-descriptions-item label="存在问题：">{{
                                    props.row.existingProblems
                                }}</el-descriptions-item>
                            </el-descriptions>
                            <!-- <el-form label-position="top" class="dialog-table-expand">
                <el-row>
                  <el-form-item label="推进状态：">
                    <span>{{
                      getDictName('tjzt', props.row.propulsiveStatus)
                    }}</span>
                  </el-form-item>
                </el-row>
                <el-row>
                  <el-form-item label="已开展的工作：">
                    <span>{{ props.row.propulsiveDetailed }}</span>
                  </el-form-item>
                </el-row>
                <el-row>
                  <el-form-item label="存在问题：">
                    <span>{{ props.row.existingProblems }}</span>
                  </el-form-item>
                </el-row>
                <el-row>
                  <el-form-item label="下一步工作打算：">
                    <span>{{ props.row.fujian }}</span>
                  </el-form-item>
                </el-row>
              </el-form> -->
                        </template>
                    </el-table-column>
                    <el-table-column label="详情" width="140">
                        <template v-slot="{row, $index}">
                            <el-tag
                                effect="dark"
                                style="cursor: pointer; font-size: 16px"
                                @click="handleDetail(row, $index)"
                                >查看详情
                            </el-tag>
                        </template>
                    </el-table-column>
                </el-table>
            </div>
            <pagenation
                class="pagenation"
                @currentChange="pageChange"
                :pageResult="params.pageBean"
            ></pagenation>
        </div>
    </div>
</template>

<script>
import utils from '@/utils.js'
import * as echarts from 'echarts'
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/districView.js'
export default {
    components: {pagenation},
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            loading: false,
            stage: '',
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 10,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'DEMAND_NO_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'a.propulsive_year_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LESS_EQUAL',
                        parentGroup: '',
                        property: 'a.propulsive_month_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                ],
                sorter: [
                    {
                        direction: 'DESC',
                        property: 'create_time_',
                    },
                ],
            },
            tableData: [],
            pieChart: null,
            pieChartData: [],
            chartLoading: false,
            ggbb_ssly: [],
            ggbb_cyzty: [],
            processData: [
                {
                    name: '纳入需求全量库',
                    value: 1,
                    num: 0,
                },
                {
                    name: '纳入需求清单交办',
                    value: 2,
                    num: 0,
                },
                {
                    name: '交办区县落实',
                    value: 3,
                    num: 0,
                },
                {
                    name: '完成销号',
                    value: 4,
                    num: 0,
                },
            ],
            tableHeight: 300,
        }
    },
    created() {
        this.$emit('searchDateChange')
    },
    mounted() {
        this.$nextTick(() => {
            this.getTableHeight()
        })
        this.$root.$on('resize', () => {
            this.getTableHeight()
        })
        this.$bus.$on('changeDate', (searchDate) => {
            this.loadData('dafault')
        })
        this.loadData('dafault')
        this.ggbb_ssly = utils.getDictItemsFromCache('ggbb_ssly')
        this.ggbb_cyzty = utils.getDictItemsFromCache('ggbb_cyzty')
    },
    methods: {
        loadData(type) {
            if (type) this.chartLoading = true
            this.loading = true
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            this.params.querys[1].value = searchDate.year
            this.params.querys[2].value = searchDate.month
            apiList.getDemandList(this.params, (res) => {
                if (res && res.domainChart && type) {
                    this.ggbb_ssly.forEach((item) => {
                        let obj = {
                            name: item.name,
                            value: 0,
                        }
                        res.domainChart.forEach((domain) => {
                            if (item.name == domain.description) {
                                obj.value = domain.commonCount
                            }
                        })
                        // res.domainChart = [{commonCount: 36, description: '党建统领'},
                        //   {commonCount: 36, description: '经济发展'},
                        //   {commonCount: 16, description: '社会民生'},
                        //   {commonCount: 4, description: '文化建设'},
                        //   {commonCount: 7, description: '平安法治'},
                        //   {commonCount: 2, description: '民主法制'},]
                        //   res.domainChart.forEach((domain) => {
                        //     if (item.name == domain.description) {
                        //         obj.value = domain.commonCount
                        //     }
                        // })
                        this.pieChartData.push(obj)
                    })
                    this.initPieChart()
                }
                if (res && res.processChart && type) {
                    this.processData.forEach((item) => {
                        res.processChart.forEach((domain) => {
                            if (item.name == domain.description) {
                                item.num = domain.commonCount
                            }
                        })
                    })
                    console.log(this.processData)
                }
                if (res && res.recordList) {
                    this.tableData = res.recordList.rows
                    this.params.pageBean.page = res.recordList.page
                    this.params.pageBean.pageSize = res.recordList.pageSize
                    this.params.pageBean.total = res.recordList.total
                }
                this.loading = false
                if (type) this.chartLoading = false
            })
        },
        handleDetail(row, index) {
            this.$nextTick(() => {
                let $table = this.$refs.myTable
                this.tableData.map((item) => {
                    if (row.id != item.id) {
                        $table.toggleRowExpansion(item, false)
                        item.expansion = false
                    } else {
                        item.expansion = !item.expansion
                    }
                })
                $table.toggleRowExpansion(row)
            })
        },
        pageChange(key) {
            this.params.pageBean.page = key
            this.loadData()
        },
        search(key) {
            this.stage = key
            this.params.querys[0].value = key
            this.params.pageBean.page = 1
            this.loadData()
        },
        initPieChart() {
            let colorList = [
                {
                    colorStart: '#53CD67',
                    colorEnd: '#2F733A',
                },
                {
                    colorStart: '#FF9800',
                    colorEnd: '#8F3E1D',
                },
                {
                    colorStart: '#1790FF',
                    colorEnd: '#1161AA',
                },
                {
                    colorStart: '#FFC000',
                    colorEnd: '#975A01',
                },
                {
                    colorStart: '#fdb9c7',
                    colorEnd: '#d4818b',
                },
                {
                    colorStart: '#fcffaa',
                    colorEnd: '#829562',
                },
            ]
            let option = {
                series: [
                    {
                        name: '改革举措表现情况',
                        type: 'pie',
                        radius: ['40%', '50%'],
                        center: ['50%', '45%'],
                        left: 0,
                        top: 0,
                        labelLine: {
                            //指示线样式设置
                            length: 15, //设置指示线的长度
                            length2: 50, //横线宽度
                            lineStyle: {
                                color: '#B1E3FF', // 设置标示线的颜色
                            },
                        },
                        label: {
                            textStyle: {
                                color: '#B1E3FF', // 改变标示文字的颜色
                                fontSize: 12, //文字大小
                            },
                            formatter: '{b} {c} \n\n',
                            padding: [0, -60],
                            alignTo: 'labelLine',
                        },
                        // itemStyle: {
                        //   color: list => {
                        //     return {
                        //       type: 'radial',
                        //       x: 0.5,
                        //       y: 0.5,
                        //       r: 1,
                        //       colorStops: [
                        //         {
                        //           offset: 0,
                        //           color: colorList[list.dataIndex]['colorStart'] // 0% 处的颜色
                        //         },
                        //         {
                        //           offset: 1,
                        //           color: colorList[list.dataIndex]['colorEnd'] // 100% 处的颜色
                        //         }
                        //       ],
                        //       global: false // 缺省为 false
                        //     }

                        //     // 注意 ！！！！！ 这里的数组一定要和实际的类目长度相等或大于，不然会缺少颜色报错
                        //     return new echarts.graphic.LinearGradient(1, 0, 0, 0, [
                        //       {
                        //         offset: 1,
                        //         color: colorList[list.dataIndex]['colorEnd']
                        //       },
                        //       {
                        //         //左、下、右、上
                        //         offset: 0,
                        //         color: colorList[list.dataIndex]['colorStart']
                        //       },
                        //       {
                        //         offset: 1,
                        //         color: colorList[list.dataIndex]['colorEnd']
                        //       }
                        //     ])
                        //   }
                        // },
                        data: this.pieChartData,
                    },
                ],
            }
            this.pieChart = echarts.init(document.getElementById('pieChart'))
            option && this.pieChart.setOption(option)
            window.addEventListener('resize', () => this.pieChart.resize())
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        getSubDictName(code, subCode, value, subValue) {
            let dict = utils.getDictItemsFromCache(code)
            let name = ''
            dict.forEach((item) => {
                if (item.value == value) {
                    console.log(item.value, value)
                    item.lowerDic[subCode].forEach((sub) => {
                        if (sub.value == subValue) {
                            name = sub.name
                        }
                    })
                }
            })
            return name
        },
        getTableHeight() {
            this.tableHeight =
                this.$refs.tableContaier.clientHeight ||
                this.$refs.tableContaier.$el.clientHeight
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-table__expand-column .cell {
  width: 0;
  height: 0;
  display: none;
}
/deep/.dialog_table.el-table td.el-table__cell {
  padding: 15PX 10PX;
}
/deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
  border-color: #ffffff;
  background: transparent;
  color: #fff;
  font-size: 18PX;
}
/deep/.el-table td.el-table__cell div {
  background: transparent;
}
/deep/.dialog_table.el-table tr:nth-of-type(2n+1) {
    background: transparent;
}
.flex {
  display: flex;
  height: 100%;
  width: 100%;
}
.table-contaier {
  height: calc(100% - 130PX);
}
.dialog-table-container {
  width: calc(100% - 400PX);
//   height: 70vh;
}
.dialog-chart-contaienr {
  width: 400PX;
  height: 550PX;
}
.chart-content {
  width: 100%;
  height: 50%;
}
#pieChart {
  width: 100%;
  height: calc(100% - 40PX);
}
.sub-title {
  width: 100%;
  height: 18PX;
  text-align: center;
  position: relative;
  font-size: 16PX;
  font-family: SimHei;
  font-weight: 800;
  color: #ffffff;
  text-shadow: 0PX 0PX 16PX #266bf2;
  margin-bottom: 10PX;
}
.sub-title::after,
.sub-title::before {
  content: '';
  position: absolute;
  top: 47%;
  width: 40PX;
  height: 4PX;
}
.sub-title::before {
  left: 26%;
  background: url('~@/assets/img/bigScreen/line63.png') no-repeat center / 100%
    100%;
}
.sub-title::after {
  right: 26%;
  background: url('~@/assets/img/bigScreen/line62.png') no-repeat center / 100%
    100%;
}
.manager-content {
  width: 100%;
  height: calc(100% - 40PX);
  text-align: center;
  padding: 20PX;
  box-sizing: border-box;
}
.manager-item {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 195PX;
  height: auto;
  color: #ffffff;
  .manager-item-inner {
    display: flex;
    justify-content: center;
    align-items: center;
    font-size: 16PX;
    background: url('~@/assets/img/bigScreen/img62@2x.png') no-repeat center /
      100% 100%;
  }
  .item-1 {
    width: 195PX;
    height: 52PX;
  }
  .item-2 {
    width: 140PX;
    height: 38PX;
  }
  .item-3 {
    width: 100PX;
    height: 30PX;
  }
  .item-4 {
    width: 74PX;
    height: 28PX;
  }
}
.item-container {
  display: flex;
  justify-content: start;
  margin-left: 20PX;
}
.manager-item-text {
  display: flex;
  align-items: center;
  font-size: 14PX;
  font-weight: 400;
  color: #fff;
  width: 160PX;
  border-bottom: 1PX solid #266bf2;
  justify-content: start;
  box-sizing: border-box;
  padding-left: 15PX;
  position: relative;
}
.manager-item-text.item-1 {
  margin-top: 15PX;
}
.manager-item-text.item-2 {
  margin-left: -15PX;
  padding-left: 25PX;
}
.manager-item-text.item-3 {
  margin-left: -30PX;
  padding-left: 25PX;
}
.manager-item-text.item-4 {
  margin-left: -45PX;
  padding-left: 25PX;
}
.manager-item-text:before {
  content: '';
  position: absolute;
  left: 0%;
  bottom: -5PX;
  width: 10PX;
  height: 10PX;
  background-color: #266bf2;
  border-radius: 10PX;
}
.manager-item-text:after {
  content: '';
  position: absolute;
  right: 0%;
  bottom: -5PX;
  width: 10PX;
  height: 10PX;
  background-color: #266bf2;
  border-radius: 10PX;
}
/deep/ .dialog-table-expand label {
  width: 120PX;
  color: #fff;
  font-family: SimHei;
}
/deep/ .el-input__inner {
  background-color: rgba(1, 47, 115, 0.6);
  border: 1PX solid #0273e9;
  color: #fff;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
